# machine-uid

Get os native machine id without root permission.

[![machine-uid on GitHub Action][action-image]][action]
[![machine-uid on crates.io][cratesio-image]][cratesio]
[![total downloads][downloads-image]][cratesio]
[![machine-uid on docs.rs][docsrs-image]][docsrs]

[action-image]: https://github.com/Hanaasagi/machine-uid/actions/workflows/rust.yml/badge.svg
[action]: https://github.com/Hanaasagi/machine-uid/actions/workflows/rust.yml
[cratesio-image]: https://img.shields.io/crates/v/machine-uid.svg
[downloads-image]: https://img.shields.io/crates/d/machine-uid
[cratesio]: https://crates.io/crates/machine-uid
[docsrs-image]: https://docs.rs/machine-uid/badge.svg
[docsrs]: https://docs.rs/machine-uid

### About machine id

In Linux, machine id is a single newline-terminated, hexadecimal, 32-character, lowercase ID. When decoded from hexadecimal, this corresponds to a 16-byte/128-bit value. This ID may not be all zeros. This ID uniquely identifies the host. It should be considered "confidential", and must not be exposed in untrusted environments. And do note that the machine id can be re-generated by root.

**Please note that on \*nix platforms, this library does not require any dependencies,
but on Windows, it requires the `winreg` dependency. So if you only need to build the \*nix version,
you can use version 0.3.0.**

### Usage

```Rust
use machine_uid;

fn main() {
    let id: String = machine_uid::get().unwrap();
    println!("{}", id);
}

```

### How it works

It get machine id from following source:

Linux or who use systemd:

```Bash
cat /var/lib/dbus/machine-id # or /etc/machine-id
```

BSD:

```Bash
cat /etc/hostid # or kenv -q smbios.system.uuid
```

OSX:

```Bash
ioreg -rd1 -c IOPlatformExpertDevice | grep IOPlatformUUID
```

Windows:

```powershell
(Get-ItemProperty -Path Registry::HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\Cryptography).MachineGuid
```

illumos:

```Bash
gethostid(3C)
```

### Supported Platform

I have tested in following platform:

- Debian 8
- OS X 10.6
- FreeBSD 10.4
- Fedora 28
- Windows 10
- OmniOS r151050

### Changelog

#### v0.5.2

- Add illumos support [#11](https://github.com/Hanaasagi/machine-uid/pull/11)
- Upgrade winreg to 0.52 [#12](https://github.com/Hanaasagi/machine-uid/pull/12)
- Upgrade bindgen to 0.69 [#12](https://github.com/Hanaasagi/machine-uid/pull/12)

#### v0.5.1

- Upgrade winreg to 0.50 [#9](https://github.com/Hanaasagi/machine-uid/pull/9)
- Upgrade bindgen to 0.66 [#8](https://github.com/Hanaasagi/machine-uid/pull/8)

#### v0.5.0

- Fix cross-compilation issue [#7](https://github.com/Hanaasagi/machine-uid/pull/7)

#### v0.4.0

- Fix x86 program run on x64 [#4](https://github.com/Hanaasagi/machine-uid/pull/4)

#### v0.3.0

- Upgrade winreg to 0.11

#### v0.2.0

- Added support for Windows

### License

[MIT License](https://github.com/Hanaasagi/machine-id/blob/master/LICENSE) Copyright (c) 2018, Hanaasagi
